contracts

package
v0.2.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package contracts declares the contract-driven runtime compiler capability.

Index

Constants

const ImportPath = "github.com/cssbruno/gowdk/addons/contracts"

ImportPath is the canonical Go import path for the contracts addon.

Variables

This section is empty.

Functions

func Addon

func Addon() gowdk.Addon

Addon enables contract-driven runtime metadata and generated adapters once the compiler integration lands.

Types

This section is empty.

Jump to