spa

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const ImportPath = "github.com/cssbruno/gowdk/addons/spa"

ImportPath is the canonical Go import path for the SPA addon.

Variables

This section is empty.

Functions

func Addon

func Addon() gowdk.Addon

Addon enables build-time prerendering.

Types

type Path

type Path = static.Path

Path contains route parameter values for one prerendered route.

type PathSet

type PathSet = static.PathSet

PathSet is produced by paths {} blocks for dynamic SPA routes.

type PrerenderedPage

type PrerenderedPage = static.PrerenderedPage

PrerenderedPage is the build-time output for one SPA route.

Jump to