static

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package static marks build-time static page output responsibilities.

Index

Constants

const ImportPath = "github.com/cssbruno/gowdk/addons/static"

ImportPath is the canonical Go import path for the static addon.

Variables

This section is empty.

Functions

func Addon

func Addon() gowdk.Addon

Addon enables build-time static page output.

Types

type Path

type Path map[string]string

Path contains route parameter values for one generated static route.

type PathSet

type PathSet []Path

PathSet is produced by paths {} blocks for dynamic static routes.

type PrerenderedPage

type PrerenderedPage struct {
	Route string
	Path  string
	HTML  response.Response
}

PrerenderedPage is the build-time output for one static page route.

Jump to