clientrt

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package clientrt emits the tiny client runtime used for partial updates.

Index

Constants

const Filename = "gowdk.js"

Filename is the conventional output name for the generated client runtime.

Variables

This section is empty.

Functions

func Source

func Source() []byte

Source returns the first client runtime for partial updates and SPA navigation enhancement.

Types

This section is empty.

Jump to