cssscope

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package cssscope builds deterministic scope and hash metadata for scoped CSS.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HashKey

func HashKey(ownerKind string, packageName string, ownerID string, source string, assetPath string) string

HashKey returns the canonical identity used for scoped CSS hashing.

func ScopeID

func ScopeID(hashKey string) string

ScopeID returns a stable CSS scope ID for a hash key.

Types

This section is empty.

Jump to