lsp

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 22, 2026 License: MPL-2.0 Imports: 25 Imported by: 0

Documentation

Overview

Package lsp implements the GOWDK Language Server Protocol entrypoint.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server handles one LSP session.

func NewServer

func NewServer(config gowdk.Config) *Server

NewServer returns a language server using the provided compiler config.

func (*Server) Serve

func (server *Server) Serve(in io.Reader, out io.Writer) error

Serve runs the JSON-RPC message loop until the client sends exit or input closes.

Jump to