project

package
v0.12.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 27, 2026 License: MPL-2.0 Imports: 32 Imported by: 0

Documentation

Overview

Package project loads project-level compiler configuration.

Index

Constants

const DefaultConfigFile = "gowdk.config.go"

DefaultConfigFile is the config file discovered from a project root.

Variables

This section is empty.

Functions

func LoadConfig added in v0.1.5

func LoadConfig(path string) (gowdk.Config, error)

LoadConfig loads an explicitly requested config file, or the required default config file when no path is provided.

func LoadConfigFile

func LoadConfigFile(path string) (gowdk.Config, error)

LoadConfigFile reads the supported SPA subset of gowdk.config.go.

func LoadConfigFileStructural added in v0.12.0

func LoadConfigFileStructural(path string) (gowdk.Config, error)

LoadConfigFileStructural loads a project configuration while validating only schema and compiler-facing policy. Required runtime values are deliberately checked later by generated-app startup or ValidateRuntimeEnvironment.

func LoadConfigStructural added in v0.12.0

func LoadConfigStructural(path string) (gowdk.Config, error)

LoadConfigStructural loads an explicit config or the required default config without requiring deployment environment values to exist in the CLI process.

func ValidateRuntimeEnvironment added in v0.12.0

func ValidateRuntimeEnvironment(config gowdk.Config, lookup func(string) (string, bool)) error

ValidateRuntimeEnvironment checks required runtime variables and secret minimums against the provided value lookup. Passing nil performs only the structural checks used during config loading.

Types

This section is empty.

Jump to