safeasset

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2026 License: MPL-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package safeasset centralizes checks for files that must not be copied into generated public or embedded output.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PrivateKeyFile

func PrivateKeyFile(base string) bool

PrivateKeyFile reports common private key filenames without extension.

func UnsafeEmbeddedDirectory

func UnsafeEmbeddedDirectory(rel string) bool

UnsafeEmbeddedDirectory reports whether a directory should be skipped when copying generated output into a generated app.

func UnsafeEmbeddedFile

func UnsafeEmbeddedFile(rel string) bool

UnsafeEmbeddedFile reports whether a file must not be embedded or served as generated static output.

Types

This section is empty.

Jump to