asset

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Manifest

type Manifest struct {
	Version int               `json:"version"`
	Files   map[string]string `json:"files"`
	Hashes  map[string]string `json:"hashes,omitempty"`
	Cache   map[string]string `json:"cache,omitempty"`
}

Manifest maps logical asset names to emitted paths.

func (Manifest) CachePolicy added in v0.1.5

func (manifest Manifest) CachePolicy(name string) string

CachePolicy returns the HTTP cache policy recorded for a logical asset name.

func (Manifest) Hash added in v0.1.5

func (manifest Manifest) Hash(name string) string

Hash returns the content hash recorded for a logical asset name.

func (Manifest) Resolve

func (manifest Manifest) Resolve(name string) string

Resolve returns the emitted path for a logical asset name.

func (Manifest) URL

func (manifest Manifest) URL(name string) string

URL returns the browser-facing URL for a logical asset name.

Jump to