Documentation
¶
Index ¶
Constants ¶
const ImportPath = "github.com/cssbruno/gowdk/addons/partial"
ImportPath is the canonical Go import path for the partial addon.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ClientHook ¶
type ClientHook string
ClientHook names lifecycle hooks emitted for the partial update client runtime.
const ( HookBeforeRequest ClientHook = "before-request" HookAfterSwap ClientHook = "after-swap" HookRequestError ClientHook = "request-error" )
Click to show internal directories.
Click to hide internal directories.