spa

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const ImportPath = "github.com/cssbruno/gowdk/addons/spa"

ImportPath is the canonical Go import path for the SPA addon.

Variables

This section is empty.

Functions

func Addon

func Addon() gowdk.Addon

Addon enables build-time prerendering.

Types

type Path

type Path map[string]string

Path contains route parameter values for one prerendered route.

type PathSet

type PathSet []Path

PathSet is produced by paths {} blocks for dynamic SPA routes.

type PrerenderedPage

type PrerenderedPage struct {
	Route string
	Path  string
	HTML  response.Response
}

PrerenderedPage is the build-time output for one SPA route.

Jump to