Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EndpointHeaderReplacement ¶
EndpointHeaderReplacement extracts the current endpoint declaration from an old endpoint syntax diagnostic message.
func MissingUseAlias ¶
MissingUseAlias extracts the missing GOWDK use alias from a diagnostic.
Types ¶
type Diagnostic ¶
Diagnostic is the small diagnostic shape needed by registry rewriters.
type Position ¶
Position is a 1-based text position.
func UseInsertionPosition ¶
UseInsertionPosition inserts use declarations before view when possible.
Click to show internal directories.
Click to hide internal directories.