project

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MPL-2.0 Imports: 26 Imported by: 0

Documentation

Overview

Package project loads project-level compiler configuration.

Index

Constants

const DefaultConfigFile = "gowdk.config.go"

DefaultConfigFile is the config file discovered from a project root.

Variables

This section is empty.

Functions

func LoadConfig added in v0.1.5

func LoadConfig(path string) (gowdk.Config, error)

LoadConfig loads an explicitly requested config file, or the required default config file when no path is provided.

func LoadConfigFile

func LoadConfigFile(path string) (gowdk.Config, error)

LoadConfigFile reads the supported SPA subset of gowdk.config.go.

Types

This section is empty.

Jump to