Documentation
¶
Overview ¶
Package project loads project-level compiler configuration.
Index ¶
Constants ¶
const DefaultConfigFile = "gowdk.config.go"
DefaultConfigFile is the config file discovered from a project root.
Variables ¶
This section is empty.
Functions ¶
func LoadConfig ¶ added in v0.1.5
LoadConfig loads an explicitly requested config file, or the required default config file when no path is provided.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.