project

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Package project loads project-level compiler configuration.

Index

Constants

const DefaultConfigFile = "gowdk.config.go"

DefaultConfigFile is the config file discovered from a project root.

Variables

This section is empty.

Functions

func LoadConfigFile

func LoadConfigFile(path string) (gowdk.Config, error)

LoadConfigFile reads the supported static subset of gowdk.config.go.

func LoadOptionalConfig

func LoadOptionalConfig(path string) (gowdk.Config, bool, error)

LoadOptionalConfig loads an explicitly requested config file, or the default config file when it exists. It reports whether a file was loaded.

Types

This section is empty.

Jump to