Documentation
¶
Overview ¶
Package safeasset centralizes checks for files that must not be copied into generated public or embedded output.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrivateKeyFile ¶
PrivateKeyFile reports common private key filenames without extension.
func UnsafeEmbeddedDirectory ¶
UnsafeEmbeddedDirectory reports whether a directory should be skipped when copying generated output into a generated app.
func UnsafeEmbeddedFile ¶
UnsafeEmbeddedFile reports whether a file must not be embedded or served as generated static output.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.