Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Attr ¶
type Attr struct {
Name string
Value string
Boolean bool
Expression bool
Spread bool
Start int
End int
}
Attr is a literal HTML or component attribute.
type Component ¶
type Component struct {
Name string
Package string
Uses map[string]string
JS []string
InlineJS []InlineScript
ScopeIDs []string
DefaultIsland string
Props []string
PropTypes map[string]clientlang.ValueType
PropDefaults map[string]string
State map[string]string
StateJSON string
Handlers map[string]clientlang.Handler
HandlersJSON string
StateTypes map[string]clientlang.ValueType
Refs map[string]clientlang.Ref
Emits map[string]clientlang.Emit
Exports map[string]clientlang.ValueType
Computed []clientlang.Computed
Body string
Nodes []Node
}
Component is a literal component template known to the view renderer and generated-output passes.
func (Component) HasStateField ¶
HasStateField reports whether a component declares local browser state with the given name.
type ComponentCall ¶
ComponentCall invokes a parsed component with literal or expression props.
type InlineScript ¶
InlineScript records browser module code declared directly inside a component source file.
Click to show internal directories.
Click to hide internal directories.