Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manifest ¶
type Manifest struct {
Version int `json:"version"`
Files map[string]string `json:"files"`
Hashes map[string]string `json:"hashes,omitempty"`
Cache map[string]string `json:"cache,omitempty"`
}
Manifest maps logical asset names to emitted paths.
func (Manifest) CachePolicy ¶ added in v0.1.5
CachePolicy returns the HTTP cache policy recorded for a logical asset name.
func (Manifest) Hash ¶ added in v0.1.5
Hash returns the content hash recorded for a logical asset name.
Click to show internal directories.
Click to hide internal directories.