package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jun 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Manifest struct {
Version int `json:"version"`
Files map[string]string `json:"files"`
}
Manifest maps logical asset names to emitted paths.
Resolve returns the emitted path for a logical asset name.
URL returns the browser-facing URL for a logical asset name.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.