Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MatchPattern ¶ added in v0.2.3
MatchPattern reports whether value matches pattern from start to end.
func ValidatePattern ¶ added in v0.2.3
ValidatePattern reports whether pattern uses the generated action validation syntax supported by MatchPattern.
Types ¶
type Result ¶
type Result struct {
Errors []Error
}
Result collects validation errors for generated actions.
func (Result) FieldMessages ¶
FieldMessages returns messages for one submitted field.
Click to show internal directories.
Click to hide internal directories.